@@ -1,21 +1,19 @@
-import io
 import pathlib
 
 import pytest_codeblocks
 
 
-def test_extract_from_buffer():
-    inp = io.StringIO(
-        """
+def test_basic(testdir):
+    string1 = """
     Lorem ipsum
     ```python
     1 + 2 + 3
     ```
     dolor sit amet
     """
-    )
-    out = pytest_codeblocks.extract_from_buffer(inp)
-    assert out == [pytest_codeblocks.CodeBlock("1 + 2 + 3\n", 3, "python")]
+    testdir.makefile(".md", string1)
+    result = testdir.runpytest("--codeblocks")
+    result.assert_outcomes(passed=1)
 
 
 # example.md against reference strings test against
@@ -28,10 +26,11 @@ def test_reference():
             10,
             "python",
         ),
-        pytest_codeblocks.CodeBlock("foobar\n", 16, "bash"),
-        pytest_codeblocks.CodeBlock("# ```import math```\n", 26, "python"),
-        pytest_codeblocks.CodeBlock("1 + 1 == 2\n", 31, "python"),
-        pytest_codeblocks.CodeBlock("1 + 1 == 2\n", 36, "python"),
+        pytest_codeblocks.CodeBlock("foobar\n", 16, "ruby"),
+        pytest_codeblocks.CodeBlock("echo abc\n", 20, "sh"),
+        pytest_codeblocks.CodeBlock("# ```import math```\n", 30, "python"),
+        pytest_codeblocks.CodeBlock("1 + 1 == 2\n", 35, "python"),
+        pytest_codeblocks.CodeBlock("1 + 1 == 2\n", 40, "python"),
     ]
     this_dir = pathlib.Path(__file__).resolve().parent
     lst = pytest_codeblocks.extract_from_file(this_dir / "example.md")
